.. _userdoc-examples:

Example Notebooks
=================

This section contains a collection of example notebooks that demonstrate the use of ZnTrack.
For the best experience they can be accessed through an interactive Jupyter-Lab provided by Binder.
The notebooks can be found in ``/examples/docs``.


.. image:: https://mybinder.org/badge_logo.svg
   :alt: Binder
   :target: https://mybinder.org/v2/gh/zincware/ZnTrack/HEAD


The notebooks are organized in the following way:


.. toctree::
    :maxdepth: 0

    01_Intro
    03_dependencies
    04_metrics_and_plots
    05_metadata
    06_named_nodes
    07_functions
    08_custom_zntrackoptions
    02_Inheritance
    09_lazy
    OptionalDVC
    jupyter
    parameter_optimization
